@@ -1,6 +1,6 @@
 all_packages = (
     'analytics',
-    'bot_settings',
+    'simple_bot_settings',
     'bot_stats',
     'command_event',
     'connect_event',
