@@ -12,7 +12,9 @@ class BotStats(utils.Cog):
     @utils.checks.is_config_set('command_data', 'github_link')
     @commands.bot_has_permissions(send_messages=True)
     async def github(self, ctx:utils.Context):
-        """Sends the GitHub Repository link"""
+        """
+        Sends the GitHub Repository link.
+        """
 
         await ctx.send(f"<{self.bot.config['command_data']['github_link']}>")
 
@@ -20,7 +22,9 @@ class BotStats(utils.Cog):
     @commands.bot_has_permissions(send_messages=True)
     @utils.checks.is_config_set('command_data', 'invite_command_permissions')
     async def invite(self, ctx:utils.Context):
-        """Gives you the bot's invite link"""
+        """
+        Gives you the bot's invite link.
+        """
 
         invite_permissions = {i: True for i in self.bot.config['command_data']['invite_command_permissions']}
         await ctx.send(f"<{self.bot.get_invite_link(**invite_permissions)}>")
@@ -29,7 +33,9 @@ class BotStats(utils.Cog):
     @commands.bot_has_permissions(send_messages=True)
     @utils.checks.is_config_set('command_data', 'vote_command_enabled')
     async def vote(self, ctx:utils.Context):
-        """Gives you a link to vote for the bot"""
+        """
+        Gives you a link to vote for the bot.
+        """
 
         bot_user_id = self.bot.config.get('oauth', {}).get('client_id', None) or self.bot.user.id
         await ctx.send(f"<https://top.gg/bot/{bot_user_id}/vote>")
@@ -38,7 +44,9 @@ class BotStats(utils.Cog):
     @commands.bot_has_permissions(send_messages=True, embed_links=True)
     @utils.checks.is_config_set('command_data', 'stats_command_enabled')
     async def stats(self, ctx:utils.Context):
-        """Gives you the stats for the bot"""
+        """
+        Gives you the stats for the bot.
+        """
 
         # Get creator info
         creator_id = self.bot.config["owners"][0]
@@ -56,16 +64,48 @@ class BotStats(utils.Cog):
         embed.add_field("Shard Count", self.bot.shard_count)
         embed.add_field("Average WS Latency", f"{(self.bot.latency * 1000):.2f}ms")
         embed.add_field("Coroutines", f"{len([i for i in asyncio.Task.all_tasks() if not i.done()])} running, {len(asyncio.Task.all_tasks())} total.")
-        if self.bot.config.get("topgg_token"):
+
+        # Get topgg data
+        if self.bot.config.get('bot_listing_api_keys', {}).get("topgg_token"):
             params = {"fields": "points,monthlyPoints"}
-            headers = {"Authorization": self.bot.config['topgg_token']}
+            headers = {"Authorization": self.bot.config['bot_listing_api_keys']['topgg_token']}
             async with self.bot.session.get(f"https://top.gg/api/bots/{self.bot.user.id}", params=params, headers=headers) as r:
                 try:
                     data = await r.json()
                 except Exception:
                     data = {}
             if "points" in data and "monthlyPoints" in data:
-                embed.add_field("Top.gg Points", f"{data['points']} ({data['monthlyPoints']} this month)")
+                embed.add_field("Bot Votes", f"[Top.gg](https://top.gg/bot/{self.bot.user.id}): {data['points']} ({data['monthlyPoints']} this month)")
+
+        # Get discordbotlist data
+        if self.bot.config.get('bot_listing_api_keys', {}).get("discordbotlist_token"):
+            async with self.bot.session.get(f"https://discordbotlist.com/api/v1/bots/{self.bot.user.id}") as r:
+                try:
+                    data = await r.json()
+                except Exception:
+                    data = {}
+            if "upvotes" in data and "metrics" in data:
+                content = {
+                    "name": "Bot Votes",
+                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['metrics']['upvotes']} ({data['upvotes']} this month)"
+                }
+                try:
+                    current_data = embed.get_field_by_key("Bot Votes")
+                    content['value'] = current_data['value'] + '\n' + content['value']
+                    embed.edit_field_by_key("Bot Votes", **content)
+                except KeyError:
+                    embed.add_field(**content)
+            elif "upvotes" in data:
+                content = {
+                    "name": "Bot Votes",
+                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['upvotes']}"
+                }
+                try:
+                    current_data = embed.get_field_by_key("Bot Votes")
+                    content['value'] = current_data['value'] + '\n' + content['value']
+                    embed.edit_field_by_key("Bot Votes", **content)
+                except KeyError:
+                    embed.add_field(**content)
 
         # Send it out wew let's go
         await ctx.send(embed=embed)
